import { VirtualElement } from '@lumino/virtualdom';
import { Menu, ContextMenu } from '@lumino/widgets';
/**
 * An object which implements a universal context menu.
 * Tweaked to use inline svg icons
 */
export declare class ContextMenuSvg extends ContextMenu {
    /**
     * Construct a new context menu.
     *
     * @param options - The options for initializing the menu.
     */
    constructor(options: ContextMenu.IOptions);
    readonly menu: MenuSvg;
}
/**
 * a widget which displays items as a canonical menu.
 * Tweaked to use inline svg icons
 */
export declare class MenuSvg extends Menu {
    /**
     * construct a new menu. Overrides the default renderer
     *
     * @param options - The options for initializing the tab bar.
     */
    constructor(options: Menu.IOptions);
    /**
     * insert a menu item into the menu at the specified index. Replaces the
     * default renderer for submenus
     *
     * @param index - The index at which to insert the item.
     *
     * @param options - The options for creating the menu item.
     *
     * @returns The menu item added to the menu.
     *
     * #### Notes
     * The index will be clamped to the bounds of the items.
     */
    insertItem(index: number, options: Menu.IItemOptions): Menu.IItem;
}
export declare namespace MenuSvg {
    function overrideDefaultRenderer(menu: Menu): void;
    /**
     * a modified implementation of the Menu Renderer
     */
    class Renderer extends Menu.Renderer {
        /**
         * Render the icon element for a menu item.
         *
         * @param data - The data to use for rendering the icon.
         *
         * @returns A virtual element representing the item icon.
         */
        renderIcon(data: Menu.IRenderData): VirtualElement;
        /**
         * Create the class name for the menu item icon.
         *
         * @param data - The data to use for the class name.
         *
         * @returns The full class name for the item icon.
         */
        createIconClass(data: Menu.IRenderData): string;
        /**
         * Render the submenu icon element for a menu item.
         *
         * @param data - The data to use for rendering the submenu icon.
         *
         * @returns A virtual element representing the submenu icon.
         */
        renderSubmenu(data: Menu.IRenderData): VirtualElement;
    }
    const defaultRenderer: Renderer;
}
